==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PrimaryKeyValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescription } from "./PrimaryKeyValueDescription";
/**
 * @hidden
 */
export let PrimaryKeyValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class PrimaryKeyValueDescriptionMetadata extends Base {
        static b(a) {
            if (PrimaryKeyValueDescriptionMetadata.a == null) {
                PrimaryKeyValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PrimaryKeyValueDescriptionMetadata.c(PrimaryKeyValueDescriptionMetadata.a);
            }
            if (a.k(PrimaryKeyValueDescriptionMetadata.a)) {
                return;
            }
            a.aa(PrimaryKeyValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Key", "Array:string");
            a.item("Value", "Collection:object:Array:Object");
        }
        static d(a) {
            PrimaryKeyValueDescriptionMetadata.b(a);
            a.ac("PrimaryKeyValue", () => new PrimaryKeyValueDescription());
            a.ab("PrimaryKeyValue", PrimaryKeyValueDescriptionMetadata.a);
        }
    }
    PrimaryKeyValueDescriptionMetadata.$t = /*@__PURE__*/ markType(PrimaryKeyValueDescriptionMetadata, 'PrimaryKeyValueDescriptionMetadata');
    PrimaryKeyValueDescriptionMetadata.a = null;
    return PrimaryKeyValueDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/PrimaryKeyValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescription } from "./PrimaryKeyValueDescription";
/**
 * @hidden
 */
export let PrimaryKeyValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class PrimaryKeyValueDescriptionMetadata extends Base {
        static b(a) {
            if (PrimaryKeyValueDescriptionMetadata.a == null) {
                PrimaryKeyValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PrimaryKeyValueDescriptionMetadata.c(PrimaryKeyValueDescriptionMetadata.a);
            }
            if (a.k(PrimaryKeyValueDescriptionMetadata.a)) {
                return;
            }
            a.ac(PrimaryKeyValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("Key", "Array:string");
            a.item("Value", "Collection:object:Array:Object");
        }
        static d(a) {
            PrimaryKeyValueDescriptionMetadata.b(a);
            a.ae("PrimaryKeyValue", () => new PrimaryKeyValueDescription());
            a.ad("PrimaryKeyValue", PrimaryKeyValueDescriptionMetadata.a);
        }
    }
    PrimaryKeyValueDescriptionMetadata.$t = /*@__PURE__*/ markType(PrimaryKeyValueDescriptionMetadata, 'PrimaryKeyValueDescriptionMetadata');
    PrimaryKeyValueDescriptionMetadata.a = null;
    return PrimaryKeyValueDescriptionMetadata;
})();
